"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ItemActionControls = void 0;
const react_1 = __importDefault(require("react"));
const tokens_1 = require("@leafygreen-ui/tokens");
const emotion_1 = require("@leafygreen-ui/emotion");
const item_action_menu_1 = require("./item-action-menu");
const constants_1 = require("./constants");
const item_action_group_1 = require("./item-action-group");
const actionControlsStyle = (0, emotion_1.css)({
    flex: 'none',
    marginLeft: 'auto',
    alignItems: 'center',
    display: 'flex',
    gap: tokens_1.spacing[100],
});
function ItemActionControls({ isVisible = true, actions, onAction, className, menuClassName, iconClassName, iconStyle, iconSize = constants_1.ItemActionButtonSize.Default, renderMode, collapseAfter = 0, collapseToMenuThreshold = 2, 'data-testid': dataTestId, }) {
    const sharedProps = {
        isVisible,
        onAction,
        className: (0, emotion_1.cx)('item-action-controls', className),
        iconClassName,
        iconStyle,
        iconSize,
        'data-testid': dataTestId,
    };
    const sharedMenuProps = {
        menuClassName,
        renderMode,
    };
    if (actions.length === 0) {
        return null;
    }
    // When user wants to show a few actions and collapse the rest into a menu
    if (collapseAfter > 0) {
        const visibleActions = actions.slice(0, collapseAfter);
        const collapsedActions = actions.slice(collapseAfter);
        return (react_1.default.createElement("div", { className: actionControlsStyle },
            react_1.default.createElement(item_action_group_1.ItemActionGroup, { ...sharedProps, actions: visibleActions }),
            react_1.default.createElement(item_action_menu_1.ItemActionMenu, { ...sharedProps, ...sharedMenuProps, actions: collapsedActions })));
    }
    const shouldShowMenu = actions.length >= collapseToMenuThreshold;
    if (shouldShowMenu) {
        return (react_1.default.createElement(item_action_menu_1.ItemActionMenu, { actions: actions, ...sharedProps, ...sharedMenuProps }));
    }
    return react_1.default.createElement(item_action_group_1.ItemActionGroup, { actions: actions, ...sharedProps });
}
exports.ItemActionControls = ItemActionControls;
//# sourceMappingURL=item-action-controls.js.map